==> haskell-listlike-4.7.2-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ListLike
version:              4.7.2
visibility:           public
id:                   ListLike-4.7.2-FJ2iznLUMAt8yNGYriJk0l
key:                  ListLike-4.7.2-FJ2iznLUMAt8yNGYriJk0l
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2008 John Goerzen
maintainer:           David Fox <dsf@seereason.com>
author:               John Goerzen
stability:            Stable
homepage:             http://github.com/ddssff/listlike
synopsis:             Generalized support for list-like structures
description:
    Generalized support for list-like structures in Haskell.

    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.

    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.

category:             list, string, text, bytestring, vector
abi:                  10b0ea88dffd30ef6ebfe226f64389a0
exposed:              True
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.CharString
    Data.ListLike.Chars Data.ListLike.DList Data.ListLike.FMList
    Data.ListLike.FoldableLL Data.ListLike.IO Data.ListLike.Instances
    Data.ListLike.String Data.ListLike.Text Data.ListLike.Text.Builder
    Data.ListLike.Text.Text Data.ListLike.Text.TextLazy
    Data.ListLike.UTF8 Data.ListLike.Utils Data.ListLike.Vector
    Data.ListLike.Vector.Generic Data.ListLike.Vector.Storable
    Data.ListLike.Vector.Unboxed Data.ListLike.Vector.Vector

import-dirs:          /usr/lib/ghc-8.10.2/site-local/ListLike-4.7.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/ListLike-4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/ListLike-4.7.2
hs-libraries:         HSListLike-4.7.2-FJ2iznLUMAt8yNGYriJk0l
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.10.0 containers-0.6.2.1
    deepseq-1.4.4.0 dlist-1.0-2P2jwmsyB9Ct1vFhzn4rW
    fmlist-0.9.4-Ehec1h15Yr5Gl7rT4eaULy text-1.2.3.2
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R
    vector-0.12.1.2-9Tv6x03Z1JF7LL7lw4fTei

haddock-interfaces:   /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html:         /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-listlike-4.7.2-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ListLike
version:              4.7.2
visibility:           public
id:                   ListLike-4.7.2-Gp3fC5Dow5rIYnVKO9Eixx
key:                  ListLike-4.7.2-Gp3fC5Dow5rIYnVKO9Eixx
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2008 John Goerzen
maintainer:           David Fox <dsf@seereason.com>
author:               John Goerzen
stability:            Stable
homepage:             http://github.com/ddssff/listlike
synopsis:             Generalized support for list-like structures
description:
    Generalized support for list-like structures in Haskell.

    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.

    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.

category:             list, string, text, bytestring, vector
abi:                  aaa3e01deba875acd6791b7bf769243a
exposed:              True
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.CharString
    Data.ListLike.Chars Data.ListLike.DList Data.ListLike.FMList
    Data.ListLike.FoldableLL Data.ListLike.IO Data.ListLike.Instances
    Data.ListLike.String Data.ListLike.Text Data.ListLike.Text.Builder
    Data.ListLike.Text.Text Data.ListLike.Text.TextLazy
    Data.ListLike.UTF8 Data.ListLike.Utils Data.ListLike.Vector
    Data.ListLike.Vector.Generic Data.ListLike.Vector.Storable
    Data.ListLike.Vector.Unboxed Data.ListLike.Vector.Vector

import-dirs:          /usr/lib/ghc-8.10.2/site-local/ListLike-4.7.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/ListLike-4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/ListLike-4.7.2
hs-libraries:         HSListLike-4.7.2-Gp3fC5Dow5rIYnVKO9Eixx
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.10.0 containers-0.6.2.1
    deepseq-1.4.4.0 dlist-1.0-5ej84cv0IrB48BysmcUNjs
    fmlist-0.9.4-Ehec1h15Yr5Gl7rT4eaULy text-1.2.3.2
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R
    vector-0.12.1.2-E9lCzNvHLtkKefSxgFoNMj

haddock-interfaces:   /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html:         /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
